@@ -4,10 +4,23 @@ use warnings;
 # ABSTRACT: scrypt support for DBIx::Class::EncodedColumn
 package DBIx::Class::EncodedColumn::Crypt::Scrypt;
 
+our $VERSION = '0.004'; # VERSION
+
 use Encode qw(is_utf8 encode_utf8);
 use Crypt::ScryptKDF 0.008 qw(scrypt_hash scrypt_hash_verify
     random_bytes);
 
+sub power_of_2 {
+    my ($x) = @_;
+
+    while($x > 1) {
+        return 0 if $x % 2 == 1;
+        $x /= 2;
+    }
+
+    return $x == 1;
+}
+
 sub make_encode_sub {
     my ($class, $col, $args) = @_;
 
@@ -17,6 +30,8 @@ sub make_encode_sub {
     $args->{saltsz}   //= 32;
     $args->{keysz}    //= 32;
 
+    die "Cost not a power of 2" unless power_of_2($args->{cost});
+
     sub {
         my ($text) = @_;
         $text = encode_utf8($text) if is_utf8($text);
@@ -50,7 +65,7 @@ DBIx::Class::EncodedColumn::Crypt::Scrypt - scrypt support for DBIx::Class::Enco
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
